---
tags:
  - prompt
author: agp
---

# Prompt

Consider documents located in the same directory as this file.

Read the 325 document carefully where all specifications has been summed into a nested structured hierarchical specification from the higher level to the more detailed ones.

Generate a coherent planning that can be used to feed an Agentic AI Coder system, step by step, with verification tests.


1. Write the result in a new file named `425.planning.results.md`.
2. User Markdown format with bulleted ticks (tasks) to organize the specifications.
3. Write an extra file `426.planning.considerations.md` with a detailed explanation of the planning, including any assumptions, constraints, risks and dependencies.

---
